@@ -323,18 +323,9 @@ def plot_histogram(returns, resample="M", bins=20,
     if grayscale:
         colors = ['silver', 'gray', 'black']
 
-    if resample in ["M", "A"]:
-        groupper = returns.index.year
-        if resample == "M":
-            groupper = [returns.index.year, returns.index.month]
-        if compounded:
-            returns = _utils.group_returns(returns, groupper, True)
-        else:
-            returns = _utils.group_returns(returns, groupper, False)
-    else:
-        apply_fnc = _stats.comp if compounded else _np.sum
-        returns = returns.fillna(0).resample(resample).apply(
-            apply_fnc).resample(resample).last()
+    apply_fnc = _stats.comp if compounded else _np.sum
+    returns = returns.fillna(0).resample(resample).apply(
+        apply_fnc).resample(resample).last()
 
     fig, ax = _plt.subplots(figsize=figsize)
     ax.spines['top'].set_visible(False)
